[or-cvs] I"m a bad person.

Roger Dingledine arma at seul.org
Tue Dec 7 15:29:57 UTC 2004


Update of /home2/or/cvsroot/tor/src/or
In directory moria.mit.edu:/home2/arma/work/onion/cvs/tor/src/or

Modified Files:
	circuitbuild.c circuituse.c or.h rephist.c 
Log Message:
I'm a bad person.
Stop treating the uint16_t's as null-terminated strings,
and stop looking at the byte after them to see if it's null,
because sometimes you're not allowed to look there.


Index: circuituse.c
===================================================================
RCS file: /home2/or/cvsroot/tor/src/or/circuituse.c,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -d -r1.36 -r1.37
--- circuituse.c	7 Dec 2004 05:33:55 -0000	1.36
+++ circuituse.c	7 Dec 2004 15:29:54 -0000	1.37
@@ -255,19 +255,17 @@
 void
 circuit_remove_handled_ports(smartlist_t *needed_ports) {
   int i;
-  uint16_t port;
-  char *portstring;
+  uint16_t *port;
 
   for (i = 0; i < smartlist_len(needed_ports); ++i) {
-    portstring = smartlist_get(needed_ports, i);
-    port = *(uint16_t*)(portstring);
-    tor_assert(port);
-    if (circuit_stream_is_being_handled(NULL, port, 2)) {
+    port = smartlist_get(needed_ports, i);
+    tor_assert(*port);
+    if (circuit_stream_is_being_handled(NULL, *port, 2)) {
 //      log_fn(LOG_DEBUG,"Port %d is already being handled; removing.", port);
       smartlist_del(needed_ports, i--);
-      tor_free(portstring);
+      tor_free(port);
     } else {
-      log_fn(LOG_DEBUG,"Port %d is not handled.", port);
+      log_fn(LOG_DEBUG,"Port %d is not handled.", *port);
     }
   }
 }

Index: or.h
===================================================================
RCS file: /home2/or/cvsroot/tor/src/or/or.h,v
retrieving revision 1.506
retrieving revision 1.507
diff -u -d -r1.506 -r1.507
--- or.h	7 Dec 2004 05:31:37 -0000	1.506
+++ or.h	7 Dec 2004 15:29:54 -0000	1.507
@@ -1451,7 +1451,7 @@
 char *rep_hist_get_bandwidth_lines(void);
 void rep_history_clean(time_t before);
 void rep_hist_note_used_port(uint16_t port, time_t now);
-char *rep_hist_get_predicted_ports(time_t now);
+smartlist_t *rep_hist_get_predicted_ports(time_t now);
 
 /********************************* rendclient.c ***************************/
 

Index: rephist.c
===================================================================
RCS file: /home2/or/cvsroot/tor/src/or/rephist.c,v
retrieving revision 1.50
retrieving revision 1.51
diff -u -d -r1.50 -r1.51
--- rephist.c	7 Dec 2004 05:33:55 -0000	1.50
+++ rephist.c	7 Dec 2004 15:29:54 -0000	1.51
@@ -666,12 +666,14 @@
   add_predicted_port(port, now);
 }
 
-#define PREFERRED_PORTS_RELEVANCE_TIME (6*3600) /* 6 hours */
+#define PREDICTED_PORTS_RELEVANCE_TIME (6*3600) /* 6 hours */
 
-/** Allocate and return a string of space-separated port numbers that
+/** Return a pointer to the list of port numbers that
  * are likely to be asked for in the near future.
+ *
+ * The caller promises not to mess with it.
  */
-char *rep_hist_get_predicted_ports(time_t now) {
+smartlist_t *rep_hist_get_predicted_ports(time_t now) {
   int i;
   uint16_t *tmp_port;
   time_t *tmp_time;
@@ -682,8 +684,9 @@
   /* clean out obsolete entries */
   for (i = 0; i < smartlist_len(predicted_ports_list); ++i) {
     tmp_time = smartlist_get(predicted_ports_times, i);
-    if (*tmp_time + PREFERRED_PORTS_RELEVANCE_TIME < now) {
+    if (*tmp_time + PREDICTED_PORTS_RELEVANCE_TIME < now) {
       tmp_port = smartlist_get(predicted_ports_list, i);
+      log_fn(LOG_DEBUG, "Expiring predicted port %d", *tmp_port);
       smartlist_del(predicted_ports_list, i);
       smartlist_del(predicted_ports_times, i);
       tor_free(tmp_port);
@@ -691,6 +694,6 @@
       i--;
     }
   }
-  return smartlist_join_strings(predicted_ports_list, " ", 0, NULL);
+  return predicted_ports_list;
 }
 



More information about the tor-commits mailing list
Index: circuitbuild.c
===================================================================
RCS file: /home2/or/cvsroot/tor/src/or/circuitbuild.c,v
retrieving revision 1.73
retrieving revision 1.74
diff -u -d -r1.73 -r1.74
--- circuitbuild.c	7 Dec 2004 09:18:25 -0000	1.73
+++ circuitbuild.c	7 Dec 2004 15:29:54 -0000	1.74
@@ -788,19 +788,25 @@
   return routelen;
 }
 
 /** Fetch the list of predicted ports, turn it into a smartlist of
  * strings, remove the ones that are already handled by an
  * existing circuit, and return it.
  */
 static smartlist_t *
 circuit_get_unhandled_ports(time_t now) {
-  char *pp = rep_hist_get_predicted_ports(now);
-  smartlist_t *needed_ports = smartlist_create();
-  smartlist_split_string(needed_ports, pp, " ", SPLIT_SKIP_SPACE|SPLIT_IGNORE_BLANK, 0);
-  tor_free(pp);
+  smartlist_t *source = rep_hist_get_predicted_ports(now);
+  smartlist_t *dest = smartlist_create();
+  uint16_t *tmp;
+  int i;
 
-  circuit_remove_handled_ports(needed_ports);
-  return needed_ports;
+  for (i = 0; i < smartlist_len(source); ++i) {
+    tmp = tor_malloc(sizeof(uint16_t));
+    memcpy(tmp, smartlist_get(source, i), sizeof(uint16_t));
+    smartlist_add(dest, tmp);
+  }
+
+  circuit_remove_handled_ports(dest);
+  return dest;
 }
 
 /** Return 1 if we already have circuits present or on the way for
@@ -811,7 +817,7 @@
   int enough;
   smartlist_t *sl = circuit_get_unhandled_ports(now);
   enough = (smartlist_len(sl) == 0);
-  SMARTLIST_FOREACH(sl, char *, cp, tor_free(cp));
+  SMARTLIST_FOREACH(sl, uint16_t *, cp, tor_free(cp));
   smartlist_free(sl);
   return enough;
 }
@@ -1000,7 +1006,7 @@
       if (router)
         break;
     }
-    SMARTLIST_FOREACH(needed_ports, char *, cp, tor_free(cp));
+    SMARTLIST_FOREACH(needed_ports, uint16_t *, cp, tor_free(cp));
     smartlist_free(needed_ports);
   }
 
@@ -788,19 +788,25 @@
 }
 
-/** Fetch the list of predicted ports, turn it into a smartlist of
- * strings, remove the ones that are already handled by an
+/** Fetch the list of predicted ports, dup it into a smartlist of
+ * uint16_t's, remove the ones that are already handled by an
  * existing circuit, and return it.
  */
